summaryrefslogtreecommitdiffstats
path: root/kontact/plugins/korganizer/todosummarywidget.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'kontact/plugins/korganizer/todosummarywidget.cpp')
-rw-r--r--kontact/plugins/korganizer/todosummarywidget.cpp14
1 files changed, 7 insertions, 7 deletions
diff --git a/kontact/plugins/korganizer/todosummarywidget.cpp b/kontact/plugins/korganizer/todosummarywidget.cpp
index 05e9ea55..7bd1be11 100644
--- a/kontact/plugins/korganizer/todosummarywidget.cpp
+++ b/kontact/plugins/korganizer/todosummarywidget.cpp
@@ -17,8 +17,8 @@
Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
As a special exception, permission is given to link this program
- with any edition of Qt, and distribute the resulting executable,
- without including the source code for Qt in the source distribution.
+ with any edition of TQt, and distribute the resulting executable,
+ without including the source code for TQt in the source distribution.
*/
#include <tqcursor.h>
@@ -53,8 +53,8 @@
#include "todosummarywidget.h"
TodoSummaryWidget::TodoSummaryWidget( TodoPlugin *plugin,
- TQWidget *parent, const char *name )
- : Kontact::Summary( parent, name ), mPlugin( plugin )
+ TQWidget *tqparent, const char *name )
+ : Kontact::Summary( tqparent, name ), mPlugin( plugin )
{
TQVBoxLayout *mainLayout = new TQVBoxLayout( this, 3, 3 );
@@ -152,14 +152,14 @@ void TodoSummaryWidget::updateView()
mLabels.append( label );
TQString sSummary = todo->summary();
- if ( todo->relatedTo() ) { // show parent only, not entire ancestry
+ if ( todo->relatedTo() ) { // show tqparent only, not entire ancestry
sSummary = todo->relatedTo()->summary() + ":" + todo->summary();
}
KURLLabel *urlLabel = new KURLLabel( this );
urlLabel->setText( sSummary );
urlLabel->setURL( todo->uid() );
urlLabel->installEventFilter( this );
- urlLabel->setTextFormat( Qt::RichText );
+ urlLabel->setTextFormat( TQt::RichText );
mLayout->addWidget( urlLabel, counter, 2 );
mLabels.append( urlLabel );
@@ -255,7 +255,7 @@ bool TodoSummaryWidget::eventFilter( TQObject *obj, TQEvent* e )
if ( e->type() == TQEvent::Enter )
emit message( i18n( "Edit To-do: \"%1\"" ).arg( label->text() ) );
if ( e->type() == TQEvent::Leave )
- emit message( TQString::null );
+ emit message( TQString() );
}
return Kontact::Summary::eventFilter( obj, e );